### Test Scripts


This will run all tests:

    python runtests.py

Beautiful html output is possible with (Unix, package `aha` required)

    ./runtests_html.sh


### Running single tests

Directly execute the scripts, e.g.


    python test_backproject.py



